function [D_DISTR, PROB_F, D_VALUE, TYPE] =crea_his(FILENAME)
% [D_DISTR, PROB_F, D_VALUE, TYPE] =crea_his(FILENAME)
%
% Create the discrete or continuous histogram and prob.function,
% i.e. the pairs pi(x),xi, i=1:Bins
% length(D_VALUE) ... 
% ... the number of discrete values of the random variable FILENAME 
% sum(PROB_F)==1
%
% INPUT
%============================
% FILENAME - Histogram name
%
% OUTPUT
%============================
% D_DISTR - Distribution Function
% PROB_F - Probability Density of Histogram
% D_VALUE - Value of Particular Histogram Bin
% TYPE - Histogram TYPE: 0 - Discrete, 1 - Piece-wise uniform

% Author: Pavel PRAKS, pavel.praks@vsb.cz
% Edited by: Petr KONECNY, petr.konecny@vsb.cz 
% VSB - Technical University Ostrava, www.vsb.cz, Czech Republic
% 04-11-2011

[Min, Max, Bins, Total, freq, TYPE]=read_his(FILENAME);

%CLEARING VARIABLES
PROB_F=[];
D_DISTR=[];
D_VALUE=[];

if TYPE == 1
 %CONTINUOUS HISTOGRAM
 d_step = (Max-Min)/(Bins);
  for i=1:Bins
  D_VALUE(i)= Min + (i-0.5)*d_step;
 end;

else 
 %DISCRETE HISTOGRAM
 TYPE = 0; % if ther is no result from read_his
 d_step = (Max-Min)/(Bins-1);
 for i=1:Bins
  D_VALUE(i)= Min + (i-1)*d_step; 
 end;
end; % if TYPE

%D_VALUE involves discrete values between Min and Max

%for each freq create the histogram
for i = 1:length(freq)
 HOW_MANY_TIMES=freq(i);
 D_DISTR=[D_DISTR, D_VALUE(i) * ones(1, HOW_MANY_TIMES)];
end;

PROB_F=freq/Total;